package de.intevation.flys.importer;

import de.intevation.flys.model.Wst;
import de.intevation.flys.model.River;

import org.hibernate.Session;
import org.hibernate.Query;

import java.util.List;
import java.util.Map;
import java.util.HashMap;

public class ImportWst
{
    protected String description;

    protected Integer kind;

    protected Map<String, ImportWstColumn> columns;

    protected Wst peer;

    public ImportWst() {
        kind = 0;
        columns = new HashMap<String, ImportWstColumn>();
    }

    public ImportWst(String description) {
        this();
        this.description = description;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public ImportWstColumn getColumn(String name) {
        ImportWstColumn column = columns.get(name);
        if (column == null) {
            column = new ImportWstColumn(this, name, null);
            columns.put(name, column);
        }
        return column;
    }

    public void storeDependencies(River river) {
        Wst wst = getPeer(river);

        for (ImportWstColumn column: columns.values()) {
            column.storeDependencies(river);
        }
    }

    public Wst getPeer(River river) {
        if (peer == null) {
            Session session = Importer.sessionHolder.get();
            Query query = session.createQuery(
                "from Wst where " +
                "river=:river and description=:description and kind=:kind");
            query.setParameter("river",       river);
            query.setParameter("description", description);
            query.setParameter("kind",        kind);
            List<Wst> wsts = query.list();
            if (wsts.isEmpty()) {
                peer = new Wst(river, description, kind);
                session.save(peer);
            }
            else {
                peer = wsts.get(0);
            }

        }
        return peer;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
